<?php

namespace WilokeProductCategoriesElementor\Shared;

class HtmlHelper
{
	public static function autoPrefix($item)
	{
		return strpos($item, WILOKE_PRODUCT_CATEGORIES_ID) === false ? WILOKE_PRODUCT_CATEGORIES_ID . '-' . $item : $item;
	}

	public static function renderStyle1(array $aItem, array $aSettings)
	{
		?>
		<div class="wil-col">
			<a href="<?php echo esc_url($aItem["link"]["url"]); ?>"
			   target="<?php echo esc_attr($aItem["link"]["target"]); ?>"
			   class="wil-collection wil-collection-style1"
			   style="--color-background-color: <?php echo esc_attr($aSettings["item_background_color"]); ?>"
			>
				<div class="wil-image">
					<?php
					if (!empty($aItem["img_url"])) {
						?>
						<img
							src="<?php echo esc_url($aItem["img_url"]) ?>"
							alt="<?php echo esc_attr($aItem["name"]); ?>"
						/>
						<?php
					}
					?>
				</div>
				<h2 class="wil-h2"
				    style="--color-text: <?php echo esc_attr($aSettings["text_color"]); ?>;--color-text-hover: <?php echo esc_attr($aSettings["text_hover_color"]); ?>;--color-text-background: <?php echo esc_attr($aSettings["text_background_color"]); ?>;">
					<?php echo esc_html($aItem["name"]); ?>
				</h2>
			</a>
		</div>
		<?php
	}

	public static function renderStyle2(array $aItem, array $aSettings)
	{
		?>
		<div class="wil-col">
			<a href="<?php echo esc_url($aItem["link"]["url"]); ?>"
			   target="<?php echo esc_attr($aItem["link"]["target"]); ?>"
			   class="wil-collection wil-collection-style2">
				<div class="wil-image">
					<?php
					if (!empty($aItem["img_url"])) {
						?>
						<img
							src="<?php echo esc_url($aItem["img_url"]) ?>"
							alt="<?php echo esc_attr($aItem["name"]); ?>"
						/>
						<?php
					}
					?>
				</div>
				<h2 class="wil-h2"
				    style="--color-text: <?php echo esc_attr($aSettings["text_color"]); ?>;--color-text-hover: <?php echo esc_attr($aSettings["text_hover_color"]); ?>;--color-text-background: <?php echo esc_attr($aSettings["text_background_color"]); ?>;">
					<?php echo esc_html($aItem["name"]); ?>
				</h2>
			</a>
		</div>
		<?php
	}

	public static function renderStyle3(array $aItem, array $aSettings)
	{
		?>
		<div class="wil-col">
			<a href="<?php echo esc_url($aItem["link"]["link"]); ?>"
			   target="<?php echo esc_attr($aItem["link"]["target"]); ?>"
			   class="wil-collection wil-collection-style3">
				<div class="wil-image">
					<?php
					if (!empty($aItem["img_url"])) {
						?>
						<img
							src="<?php echo esc_url($aItem["img_url"]) ?>"
							alt="<?php echo esc_attr($aItem["name"]); ?>"
						/>
						<?php
					}
					?>
				</div>
				<h2 class="wil-h2"
				    style="--color-text: <?php echo esc_attr($aSettings["text_color"]); ?>;--color-text-hover: <?php echo esc_attr($aSettings["text_hover_color"]); ?>;--color-text-background: <?php echo esc_attr($aSettings["text_background_color"]); ?>;">
					<?php echo esc_html($aItem["name"]); ?>
				</h2>
			</a>
		</div>
		<?php
	}

	public static function renderStyle4(array $aItem, array $aSettings)
	{
		?>
		<div class="wil-col">
			<a href="<?php echo esc_url($aItem["link"]["link"]); ?>"
			   target="<?php echo esc_attr($aItem["link"]["target"]); ?>"
			   class="wil-collection wil-collection-style4">
				<div class="wil-image">
					<?php
					if (!empty($aItem["img_url"])) {
						?>
						<img
							src="<?php echo esc_url($aItem["img_url"]) ?>"
							alt="<?php echo esc_attr($aItem["name"]); ?>"
						/>
						<?php
					}
					?>
				</div>
				<h2
				    style="--color-text: <?php echo esc_attr($aSettings["text_color"]); ?>;--color-text-hover: <?php echo esc_attr($aSettings["text_hover_color"]); ?>;--color-text-background: <?php echo esc_attr($aSettings["text_background_color"]); ?>;">
					<div  class="wil-h2"><?php echo esc_html($aItem["name"]); ?></div>
				</h2>
			</a>
		</div>
		<?php
	}

	public static function renderItem(array $aItem, array $aSettings = [])
	{
		if (!empty($aItem["featured_image"]) && !empty($aItem["featured_image"]["id"])) {
			$aItem["img_url"] = wp_get_attachment_image_url($aItem["featured_image"]["id"], "large");
		} else {
			$thumbnailId = get_term_meta($aItem["cat_id"], 'thumbnail_id', true);
			$aItem["img_url"] = wp_get_attachment_image_url($thumbnailId, "large");
		}

		if (!empty($aItem["custom_link"]) && !empty($aItem["custom_link"]["url"])) {
			$link = !empty($aItem["link"]) && !empty($aItem["link"]["url"]) ? $aItem["link"]["url"] : "";
			$target = !empty($aItem["link"]) && $aItem["link"]["is_external"] == "on" ? "_blank" : "_self";
			$name = !empty($aItem["custom_name"]) ? $aItem["custom_name"] : "";
		} else {
			$oTerm = get_term($aItem["cat_id"], "product_cat");
			$link = get_term_link($oTerm);
			$target = "_self";
			$name = $oTerm->name;
		}

		$aItem["link"] = [
			"url"    => $link,
			"target" => $target
		];

		$aItem["name"] = $name;

		switch ($aSettings["style"]) {
			case "style1":
				self::renderStyle1($aItem, $aSettings);
				break;
			case "style2":
				self::renderStyle2($aItem, $aSettings);
				break;
			case "style3":
				self::renderStyle3($aItem, $aSettings);
				break;
			case "style4":
				self::renderStyle4($aItem, $aSettings);
				break;
		}
	}
}
