<?php

namespace WilokeProductCategoriesElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;
use WilokeProductCategoriesElementor\Shared\HtmlHelper;

class ProductCategoriesWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return [WILOKE_PRODUCT_CATEGORIES_ID . "-grid", WILOKE_PRODUCT_CATEGORIES_ID];
	}

	public function get_script_depends()
	{
		return [WILOKE_PRODUCT_CATEGORIES_ID];
	}

	public function get_name()
	{
		return WILOKE_PRODUCT_CATEGORIES_ID . '-settings';
	}

	public function get_title()
	{
		return "Wiloke Product Categories";
	}

	public function get_icon()
	{
		return 'eicon-product-categories';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	protected function getTerms()
	{
		$aTerms = get_terms([
			'taxonomy'   => 'product_cat',
			'hide_empty' => false
		]);

		if (empty($aTerms) || is_wp_error($aTerms)) {
			return [
				"" => esc_html__("No category found", "wiloke-product-categories-elementor")
			];
		}

		$aOptions = [
			"---" => esc_html__("Select a category", "wiloke-product-categories-elementor")
		];

		foreach ($aTerms as $oTerm) {
			$aOptions[$oTerm->term_id] = $oTerm->name;
		}

		return $aOptions;
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'wiloke_product_categories_heading_section_content',
			[
				'label' => esc_html__('Heading Settings', 'wiloke-product-categories-elementor'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			"heading",
			[
				"label"   => esc_html__("Title", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::TEXT,
				"default" => "Best selling collections"
			]
		);

		$this->add_control(
			"description",
			[
				"label"   => esc_html__("Description", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::TEXTAREA,
				"default" => "Discover our curated collection of stylish clothing and accessories. Elevate your fashion game with us!"
			]
		);

		$this->add_control(
			"heading_alignment",
			[
				"label"   => esc_html__("Heading Alignment", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"default" => "center",
				"options" => [
					"left"   => esc_html__("Left", "wiloke-product-categories-elementor"),
					"right"  => esc_html__("Right", "wiloke-product-categories-elementor"),
					"center" => esc_html__("Center", "wiloke-product-categories-elementor")
				]
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'wiloke_product_categories_item_section_content',
			[
				'label' => esc_html__('Items Settings', 'wiloke-product-categories-elementor'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			"style",
			[
				"label"   => esc_html__("Style", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"options" => [
					"style1" => esc_html__("Style 1", "wiloke-product-categories-elementor"),
					"style2" => esc_html__("Style 2", "wiloke-product-categories-elementor"),
					"style3" => esc_html__("Style 3", "wiloke-product-categories-elementor"),
					"style4" => esc_html__("Style 4", "wiloke-product-categories-elementor")
				],
				"default" => "style1"
			]
		);

		// Repeater control for Title and Description fields
		$repeater = new Repeater();

		$repeater->add_control(
			"cat_id",
			[
				"label"   => esc_html__("Category", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT2,
				"options" => $this->getTerms()
			]
		);

		$repeater->add_control(
			"custom_name",
			[
				"label"       => esc_html__("Custom Name", "wiloke-product-categories-elementor"),
				"description" => esc_html__("This setting overrides the Category name.", "wiloke-product-categories-elementor"),
				"type"        => Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			"custom_link",
			[
				"label"       => esc_html__("Custom Link", "wiloke-product-categories-elementor"),
				"description" => esc_html__("This setting overrides the Category link.", "wiloke-product-categories-elementor"),
				"type"        => Controls_Manager::URL
			]
		);

		$repeater->add_control(
			"featured_image",
			[
				"label"       => esc_html__("Featured Image", "wiloke-product-categories-elementor"),
				"description" => esc_html__("This setting  overrides the Category featured image.",
					"wiloke-product-categories-elementor"),
				"type"        => Controls_Manager::MEDIA
			]
		);

		// Repeatable control for Title and Description fields
		$this->add_control(
			'items',
			[
				'label'  => esc_html__('Items', 'wiloke-swaying-photo-gallery'),
				'type'   => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls()
			]
		);

		$this->end_controls_section();;

		$this->start_controls_section(
			'wiloke_product_categories_bottom_section_content',
			[
				'label' => esc_html__('Bottom Settings', 'wiloke-product-categories-elementor'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			"view_all_btn_name",
			[
				"label"   => esc_html__("View All Button Name", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::TEXT,
				"default" => "View All Collections"
			]
		);

		$this->add_control(
			"view_all_btn_link",
			[
				"label" => esc_html__("View All Button Link", "wiloke-product-categories-elementor"),
				"type"  => Controls_Manager::URL
			]
		);

		$this->add_control(
			"view_all_btn_icon",
			[
				"label"   => esc_html__("View All Button Icon", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::ICON,
				"default" => "fa fa-arrow-right"
			]
		);

		$this->add_control(
			"view_all_btn_text_color",
			[
				"label"   => esc_html__("View All Button Text Color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#000"
			]
		);

		$this->add_control(
			"view_all_btn_hover_color",
			[
				"label"   => esc_html__("View All Button Hover Color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#000"
			]
		);

		$this->add_control(
			"view_all_btn_bg_color",
			[
				"label"   => esc_html__("View All Button Background Color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#e5e5e5"
			]
		);

		$this->add_control(
			"view_all_btn_hover_bg_color",
			[
				"label"   => esc_html__("View All Button Hover Background Color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#33c9c4"
			]
		);

		$this->add_control(
			"button_alignment",
			[
				"label"   => esc_html__("Alignment", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"default" => "center",
				"options" => [
					"left"   => esc_html__("Left", "wiloke-product-categories-elementor"),
					"right"  => esc_html__("Right", "wiloke-product-categories-elementor"),
					"center" => esc_html__("Center", "wiloke-product-categories-elementor")
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'wiloke_product_categories_section_style',
			[
				'label' => esc_html__('Extra Settings', 'wiloke-product-categories-elementor'),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			"text_color",
			[
				"label"   => esc_html__("Text color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#33c9c4"
			]
		);

		$this->add_control(
			"text_hover_color",
			[
				"label"   => esc_html__("Text hover color", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#33c9c4"
			]
		);

		$this->add_control(
			"text_background_color",
			[
				"label"       => esc_html__("Button Background Color", "wiloke-product-categories-elementor"),
				"description" => esc_html__("This setting is only applied for Style 4", "wiloke-product-categories-elementor"),
				"type"        => Controls_Manager::COLOR,
				"default"     => "#33c9c4"
			]
		);

		$this->add_control(
			"item_background_color",
			[
				"label"       => esc_html__("Item Background Color", "wiloke-product-categories-elementor"),
				"description" => esc_html__("This setting is only applied for Style 1", "wiloke-product-categories-elementor"),
				"type"        => Controls_Manager::COLOR,
				"default"     => "#F2FCEF"
			]
		);

		$this->add_control(
			"lg_items_per_row",
			[
				"label"   => esc_html__("Items Per Row (>= 992px)", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"options" => [
					"wil-row-cols-lg-8" => esc_html__("8 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-7" => esc_html__("7 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-6" => esc_html__("6 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-5" => esc_html__("5 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-4" => esc_html__("4 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-3" => esc_html__("3 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-lg-2" => esc_html__("2 items per row", "wiloke-product-categories-elementor")
				],
				"default" => "wil-row-cols-lg-4"
			]
		);

		$this->add_control(
			"md_items_per_row",
			[
				"label"   => esc_html__("Items Per Row (>= 768px)", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"options" => [
					"wil-row-cols-md-8" => esc_html__("8 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-7" => esc_html__("7 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-6" => esc_html__("6 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-5" => esc_html__("5 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-4" => esc_html__("4 items  per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-3" => esc_html__("3 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-md-2" => esc_html__("2 items per row", "wiloke-product-categories-elementor")
				],
				"default" => "wil-row-cols-md-4"
			]
		);

		$this->add_control(
			"sm_items_per_row",
			[
				"label"   => esc_html__("Items Per Row (>= 576px)", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"options" => [
					"wil-row-cols-sm-6" => esc_html__("6 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-sm-5" => esc_html__("5 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-sm-4" => esc_html__("4 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-sm-3" => esc_html__("3 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-sm-2" => esc_html__("2 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-sm-1" => esc_html__("1 items per row", "wiloke-product-categories-elementor"),
				],
				"default" => "wil-row-cols-sm-4"
			]
		);

		$this->add_control(
			"xs_items_per_row",
			[
				"label"   => esc_html__("Items Per Row (< 576px)", "wiloke-product-categories-elementor"),
				"type"    => Controls_Manager::SELECT,
				"options" => [
					"wil-row-cols-6" => esc_html__("6 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-5" => esc_html__("5 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-4" => esc_html__("4 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-3" => esc_html__("3 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-2" => esc_html__("2 items per row", "wiloke-product-categories-elementor"),
					"wil-row-cols-1" => esc_html__("1 items per row", "wiloke-product-categories-elementor"),
				],
				"default" => "wil-row-cols-2"
			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$aSettings = $this->get_settings_for_display();

		if (empty($aSettings)) {
			return;
		}

		if (empty($aSettings["items"])) {
			return;
		}

		$aWrapperClasses[] = "wil-row";
		$aWrapperClasses[] = $aSettings["lg_items_per_row"];
		$aWrapperClasses[] = $aSettings["md_items_per_row"];
		$aWrapperClasses[] = $aSettings["sm_items_per_row"];
		$aWrapperClasses[] = $aSettings["xs_items_per_row"];
		?>
		<div class="wil-product-categories-wrapper wil-container">


			<?php if (!empty($aSettings["heading"]) || !empty($aSettings["description"])) : ?>
				<div class="wil-col-xs-12 wil-col-sm-12 wil-col-md-12 wil-col-lg-12 wil-mb-20">
					<div class="wil-heading" style="--alignment: <?php echo esc_attr($aSettings["heading_alignment"]); ?>">
						<?php if (!empty($aSettings["heading"])) : ?>
							<h2 class="wil-heading__title"><?php echo esc_html($aSettings["heading"]); ?></h2>
						<?php endif; ?>

						<?php if (!empty($aSettings["description"])) : ?>
							<p class="wil-heading__description">
								<?php echo esc_html($aSettings["description"]); ?>
							</p>
						<?php endif; ?>
					</div>
				</div>
			<?php endif; ?>

			<div class="wil-col-xs-12 wil-col-sm-12 wil-col-md-12 wil-col-lg-12">
				<div
					class="wil-row <?php echo esc_attr(implode(" ", $aWrapperClasses)); ?>"
				>
					<?php
					foreach ($aSettings["items"] as $aItem) {
						HtmlHelper::renderItem($aItem, $aSettings);
					}
					?>
				</div>
			</div>

			<?php
			$link = !empty($aSettings["view_all_btn_link"]) && !empty($aSettings["view_all_btn_link"]["url"]) ?
				$aSettings["view_all_btn_link"]["url"] : "";
			$target = !empty($aSettings["view_all_btn_link"]) && $aSettings["view_all_btn_link"]["is_external"] == "on" ? "_blank" :
				"_self";
			?>

			<?php if (!empty($link)) : ?>
				<div class="wil-col-xs-12 wil-col-sm-12 wil-col-md-12 wil-col-lg-12" style="text-align: <?php echo esc_attr($aSettings["button_alignment"]); ?>;">
					<a class="wil-btn-view-more"
					   style="--button-color: <?php echo esc_attr($aSettings["view_all_btn_text_color"]) ?>;
						   --button-bg-color: <?php echo esc_attr($aSettings["view_all_btn_bg_color"]) ?>;
						   --button-hover-color: <?php echo esc_attr($aSettings["view_all_btn_hover_color"]) ?>;
						   --button-hover-bg-color: <?php echo esc_attr($aSettings["view_all_btn_hover_bg_color"]) ?>"
					   target="<?php echo esc_attr($target); ?>"
					   href="<?php echo esc_url($link); ?>">
						<span><?php echo esc_html($aSettings["view_all_btn_name"]) ?></span>
						<span><i class="<?php echo esc_attr($aSettings["view_all_btn_icon"]); ?>"></i></span>
					</a>
				</div>
			<?php endif; ?>
		</div>
		<?php
	}
}
